Learn R Programming

linkspotter (version 1.3.0)

BeEFdiscretization.numfact: BeEF: Best Equal-Frequency discretization

Description

Discretize a quantitative variable by optimizing the obtained the Normalized Mutual Information with a target qualitative variable

Usage

BeEFdiscretization.numfact(
  continuousY,
  factorX,
  includeNA = T,
  showProgress = F
)

Arguments

continuousY

a vector of numeric.

factorX

a vector of factor.

includeNA

a boolean. TRUE to include NA value as a factor level.

showProgress

a boolean to decide whether to show the progress bar.

Value

a factor.

Examples

Run this code
# NOT RUN {
# calculate a correlation dataframe
data(iris)
discreteSepalLength=BeEFdiscretization.numfact(continuousY=iris$Sepal.Length,factorX=iris$Species)
summary(discreteSepalLength)

# }

Run the code above in your browser using DataLab