powered by
Discretize two quantitative variables by optimizing the obtained the Normalized Mutual Information
BeEFdiscretization.numnum( continuousX, continuousY, maxNbBins = 100, includeNA = T, showProgress = F )
a vector of numeric.
an integer corresponding to the number of bins limitation (for computation time limitation), maxNbBins=100 by default.
a boolean. TRUE to include NA value as a factor level.
a boolean to decide whether to show the progress bar.
a list of two factors.
# NOT RUN { # calculate a correlation dataframe data(iris) disc=BeEFdiscretization.numnum(iris$Sepal.Length,iris$Sepal.Width) summary(disc$x) summary(disc$y) # }
Run the code above in your browser using DataLab