Computation of correlation matrices, variable clustering and the customizable user interface to visualize them using a graph together with variables distributions and cross plots.
linkspotterComplete(
dataset,
targetVar = NULL,
corMethods = c("pearson", "spearman", "kendall", "mic", "MaxNMI"),
maxNbBins = 100,
defaultMinCor = 0.3,
defaultCorMethod = corMethods[length(corMethods)],
clusteringCorMethod = defaultCorMethod,
nbCluster = 1:9,
printInfo = T,
appTitle = "Linkspotter",
htmlTop = "",
htmlBottom = ""
)the dataframe which variables bivariate correlations are to be analyzed.
a vector of character strings corresponding to the names of the target variables. If not NULL, correlation coefficients are computed only with that target variables.
a vector of correlation coefficients to compute. The available coefficients are
the following : c("pearson","spearman","kendall","mic","distCor","MaxNMI"). It is not case
sensitive and still work if only the beginning of the word is put (e.g. pears).
an integer used if corMethods include 'MaxNMI'. It corresponds to the number of bins limitation (for computation time limitation), maxNbBins=100 by default.
a double between 0 and 1. It is the minimal correlation absolute value to consider for the first graph plot.
a string. One of "pearson","spearman","kendall","mic", "distCor" or "MaxNMI". It is the correlation coefficient to consider for the first graph plot.
a string. One of "pearson","spearman","kendall","mic", "distCor" or "MaxNMI". It is the correlation coefficient to consider for the variables clustering.
an integer. It is the number of clusters to compute.
a boolean indicating whether to print on the console some information about the dataset and the estimated computation time.
a string taken as the title of the user interface.
a character string that enable to customize your shiny app by adding an HTML code in the HEAD tag.
a character string that enable to customize your shiny app by adding an HTML code at the end of the BODY tag.
a list containing all the material enabling to analyze correlations:
computationTime: a string
run_it: a shiny.appobj object enable to deploy instantly the user interface for a
customizable visualization.
dataset: the initial dataset
corDF: a the correlation data.frame including values for all coefficients
corMatrices: a list of correlation matrices
corGroups: data.frame a data.frame list
clusteringCorMethod: a character
defaultMinCor: a numeric
defaultCorMethod: a string
corMethods: vector of strings
# NOT RUN {
# run linkspotter on iris example data
data(iris)
lsOutputIris<-linkspotterComplete(iris)
summary(lsOutputIris)
# }
# NOT RUN {
# launch the UI
lsOutputIris$launchShiny(option=list(port=8000))
# }
# NOT RUN {
# }
Run the code above in your browser using DataLab