powered by
Computes the MaxNMI between the two variables whatever their types, by discretizing using Best Equal-Frequency-based discretization (BeEF) if necessary.
maxNMI(x, y, includeNA = T, maxNbBins = 100, showProgress = F)
a vector of numeric or factor.
a boolean. TRUE to include NA value as a factor level.
an integer corresponding to the number of bins limitation (for computation time limitation), maxNbBins=100 by default.
a boolean to decide whether to show the progress bar.
a double between 0 and 1 corresponding to the MaxNMI.
# NOT RUN { # calculate a correlation dataframe data(iris) maxNMI(iris$Sepal.Length,iris$Species) maxNMI(iris$Sepal.Length,iris$Sepal.Width) # }
Run the code above in your browser using DataLab