powered by
Discretize a quantitative variable by optimizing the obtained the Normalized Mutual Information with a target qualitative variable
BeEFdiscretization.numfact( continuousY, factorX, includeNA = T, showProgress = F )
a vector of numeric.
a vector of factor.
a boolean. TRUE to include NA value as a factor level.
a boolean to decide whether to show the progress bar.
a factor.
# NOT RUN { # calculate a correlation dataframe data(iris) discreteSepalLength=BeEFdiscretization.numfact(continuousY=iris$Sepal.Length,factorX=iris$Species) summary(discreteSepalLength) # }
Run the code above in your browser using DataLab